==> swiss-army-knife-0.0.32.crate: swiss-army-knife-0.0.32/src/a_to_z/mod.rs <==
// This file is part of olympus-xmp. It is subject to the license terms in the COPYRIGHT file found in the top-level directory of this distribution and at https://raw.githubusercontent.com/raphaelcohn/olympus-xmp/master/COPYRIGHT. No part of olympus-xmp, including this file, may be copied, modified, propagated, or distributed except according to the terms contained in the COPYRIGHT file.
// Copyright © 2022 The developers of olympus-xmp. See the COPYRIGHT file in the top-level directory of this distribution and at https://raw.githubusercontent.com/raphaelcohn/olympus-xmp/master/COPYRIGHT.

include!("Colon.rs");
include!("Hyphen.rs");
include!("LineFeed.rs");
include!("MinusSign.rs");
include!("Percent.rs");
include!("Period.rs");
include!("PlusSign.rs");
include!("Slash.rs");
include!("Space.rs");
include!("_0.rs");
include!("_9.rs");
include!("a.rs");
include!("b.rs");
include!("c.rs");
include!("d.rs");
include!("e.rs");
include!("f.rs");
include!("g.rs");
include!("h.rs");
include!("i.rs");
include!("j.rs");
include!("k.rs");
include!("l.rs");
include!("m.rs");
include!("n.rs");
include!("o.rs");
include!("p.rs");
include!("q.rs");
include!("r.rs");
include!("s.rs");
include!("t.rs");
include!("u.rs");
include!("v.rs");
include!("w.rs");
include!("x.rs");
include!("y.rs");
include!("z.rs");
include!("A_.rs");
include!("B_.rs");
include!("C_.rs");
include!("D_.rs");
include!("E_.rs");
include!("F_.rs");
include!("G_.rs");
include!("H_.rs");
include!("I_.rs");
include!("J_.rs");
include!("K_.rs");
include!("L_.rs");
include!("M_.rs");
include!("N_.rs");
include!("O_.rs");
include!("P_.rs");
include!("Q_.rs");
include!("R_.rs");
include!("S_.rs");
include!("T_.rs");
include!("U_.rs");
include!("V_.rs");
include!("W_.rs");
include!("X_.rs");
include!("Y_.rs");
include!("Z_.rs");

==> swiss-army-knife-0.0.33.crate: swiss-army-knife-0.0.33/src/a_to_z/mod.rs <==
// This file is part of olympus-xmp. It is subject to the license terms in the COPYRIGHT file found in the top-level directory of this distribution and at https://raw.githubusercontent.com/raphaelcohn/olympus-xmp/master/COPYRIGHT. No part of olympus-xmp, including this file, may be copied, modified, propagated, or distributed except according to the terms contained in the COPYRIGHT file.
// Copyright © 2022 The developers of olympus-xmp. See the COPYRIGHT file in the top-level directory of this distribution and at https://raw.githubusercontent.com/raphaelcohn/olympus-xmp/master/COPYRIGHT.


include!("A_.rs");
include!("AtSign.rs");
include!("B_.rs");
include!("C_.rs");
include!("Caret.rs");
include!("CloseSquareBracket.rs");
include!("Colon.rs");
include!("D_.rs");
include!("DoubleQuote.rs");
include!("E_.rs");
include!("F_.rs");
include!("G_.rs");
include!("H_.rs");
include!("Hash.rs");
include!("Hyphen.rs");
include!("I_.rs");
include!("J_.rs");
include!("K_.rs");
include!("L_.rs");
include!("LineFeed.rs");
include!("M_.rs");
include!("MinusSign.rs");
include!("N_.rs");
include!("O_.rs");
include!("OpenAngleBracket.rs");
include!("OpenSquareBracket.rs");
include!("P_.rs");
include!("Percent.rs");
include!("Period.rs");
include!("PlusSign.rs");
include!("Q_.rs");
include!("QuestionMark.rs");
include!("R_.rs");
include!("S_.rs");
include!("Slash.rs");
include!("Space.rs");
include!("T_.rs");
include!("Tab.rs");
include!("U_.rs");
include!("Underscore.rs");
include!("V_.rs");
include!("W_.rs");
include!("X_.rs");
include!("Y_.rs");
include!("Z_.rs");
include!("_0.rs");
include!("_1.rs");
include!("_2.rs");
include!("_4.rs");
include!("_5.rs");
include!("_9.rs");
include!("a.rs");
include!("b.rs");
include!("c.rs");
include!("d.rs");
include!("e.rs");
include!("f.rs");
include!("g.rs");
include!("h.rs");
include!("i.rs");
include!("j.rs");
include!("k.rs");
include!("l.rs");
include!("m.rs");
include!("n.rs");
include!("o.rs");
include!("p.rs");
include!("q.rs");
include!("r.rs");
include!("s.rs");
include!("t.rs");
include!("u.rs");
include!("v.rs");
include!("w.rs");
include!("x.rs");
include!("y.rs");
include!("z.rs");
